==> moodle-1.4.3.tgz: moodle/lang/fi/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['addresource'] = 'Lis aineisto';
$string['chooseafile'] = 'Valitse tai lhet tiedosto';
$string['chooseparameter'] = 'Valitse parametri';
$string['configdefaulturl'] = 'Tt kytetn esimerkkiosoitteena, kun listn uusia URL-osoiteen sisltvi aineistoja.';
$string['configfilterexternalpages'] = 'Tm asetus aiheuttaa kaikkien ulkoisten aineistoiden suodattamisen sivuston suotimien lpi. Tmn toiminnon kytkeminen plle hidastaa sivustoa, kyt sit vain, jos et muuta voi.';
$string['configframesize'] = 'Kun WWW-sivu tai palvelimelle tallennettu tiedosto on osa kehyst, tm arvo on ylkehyksen koko pikselein (sislt navigointipalkit).';
$string['configparametersettings'] = 'Tss voit mritell oletusarvot asetuksille mit kytetn uusia resursseja listess. Tmn jlkeen oletusasetukset mrytyvt kyttjn asetusten mukaan.';
$string['configpopup'] = 'Jos uusi aineisto on mahdollista nytt ponnahdusikkunassa, otetetaanko ponnahdusikkuna kyttn?';
$string['configpopupdirectories'] = 'Nytetnk ponnahdusikkunoissa hakemistolinkit?';
$string['configpopupheight'] = 'Ponnahdusikkunoiden korkeus?';
$string['configpopuplocation'] = 'Nytetnk ponnahdusikkunoissa sijanti?';
$string['configpopupmenubar'] = 'Nytetnk ponnahdusikkunoissa valikkorivi?';
$string['configpopupresizable'] = 'Voiko ponnahdusikkunoiden kokoa muuttaa?';
$string['configpopupscrollbars'] = 'Nytetnk ponnahdusikkunoissa vierityspalkit?';
$string['configpopupstatus'] = 'Nytetnk ponnahdusikkunoissa tilarivi?';
$string['configpopuptoolbar'] = 'Nytetnk ponnahdusikkunoissa tykalurivi?';
$string['configpopupwidth'] = 'Ponnahdusikkunoiden leveys?';
$string['configsecretphrase'] = 'Tm mritt salasanan jota kytet lhettyjen tietojen salaamiseen.';
$string['configwebsearch'] = 'Kun list WWW-sivun tai -linkin osoite, tt osoitetta tarjotaan kyttjlle etsimisen helpottamiseksi (esimerkiksi sopivan hakukoneen URL).';
$string['configwindowsettings'] = 'Tss mritetn oletus arvot Ikkunan asetuksille kun uusia resursseja listn ensikerran. Tmn jlkeen oletusasetukset mrytyvt kyttjn asetusten mukaan.';
$string['directlink'] = 'Suora linkki thn tiedostoon';
$string['directoryinfo'] = 'Kaikki valitun hakemiston tiedostot nytetn';
$string['display'] = 'Ikkuna';
$string['editingaresource'] = 'Aineiston muokkaus';
$string['encryptedcode'] = 'Suojaa koodi';
$string['example'] = 'Esimerkki';
$string['exampleurl'] = 'http://www.esimerkki.fi/jokuhakemisto/jokutiedosto.html';
$string['fetchclienterror'] = 'Selaimelle tapahtui virhe sivua haettaessa (ehk virheellinen osoite)';
$string['fetcherror'] = 'Tapahtui virhe sivua haettaessa.';
$string['fetchservererror'] = 'Etpalvelimella tapahtui virhe haettaessa sivua (ehk ohjelma virhe)';
$string['filename'] = 'Tiedoston nimi';
$string['filtername'] = 'Aineiston automaattilinkitys';
$string['frameifpossible'] = 'Pane aineisto kehykseen ja jt sivuston navigointipainikkeet nkyviin.';
$string['fulltext'] = 'Teksti';
$string['htmlfragment'] = 'HTML';
$string['maindirectory'] = 'Tiedostojen hakemisto';
$string['modulename'] = 'Aineisto';
$string['modulenameplural'] = 'Aineistot';
$string['neverseen'] = 'Lukematta';
$string['newdirectories'] = 'Nyt linkkirivi';
$string['newfullscreen'] = 'Tyt koko ruutu';
$string['newheight'] = 'Ikkunan oletuskorkeus pikselein';
$string['newlocation'] = 'Nyt osoiterivi';
$string['newmenubar'] = 'Nyt valikkorivi';
$string['newresizable'] = 'Salli ikkunan koon muutos';
$string['newscrollbars'] = 'Nyt vierityspalkki';
$string['newstatus'] = 'Nyt tilarivi';
$string['newtoolbar'] = 'Nyt tykalurivi';
$string['newwidth'] = 'Ikkunan oletusleveys pikselein';
$string['newwindow'] = 'Uusi ikkuna';
$string['newwindowopen'] = 'Nyt linkki uudessa ikkunassa';
$string['note'] = 'Huomaa';
$string['notefile'] = 'Listksesi tiedostoja kurssille (jotta ne nkysivt tss listassa) kyt 
<a href=\"$a\">Tiedostot</A>-tykalua.';
$string['notypechosen'] = 'Sinun pit valita luettavan aineiston tyyppi.  Kyt selaimen Takaisin-painiketta ja yrit uudelleen.';
$string['pagedisplay'] = 'Nyt aineisto nykyisess ikkunassa';
$string['pagewindow'] = 'Samassa ikkunassa';
$string['parameter'] = 'Asetus';
$string['parameters'] = 'Asetukset';
$string['popupresource'] = 'Tmn aineiston tulee nky ponnahdusikkunassa.';
$string['popupresourcelink'] = 'Jos et viel klikannut, klikkaa tss: $a';
$string['resourcetype'] = 'Aineiston tyyppi';
$string['resourcetype1'] = 'Referenssi';
$string['resourcetype2'] = 'Websivu';
$string['resourcetype3'] = 'Tiedosto';
$string['resourcetype4'] = 'Teksti';
$string['resourcetype5'] = 'Weblinkki';
$string['resourcetype6'] = 'HTML teksti';
$string['resourcetype7'] = 'Ohjelma';
$string['resourcetype8'] = 'Wikiteksti';
$string['resourcetype9'] = 'Hakemisto';
$string['resourcetypedirectory'] = 'Nyt hakemisto';
$string['resourcetypefile'] = 'Linkit  tiedostoon tai web-sivuun';
$string['resourcetypehtml'] = 'Tee uusi web-sivu';
$string['resourcetypelabel'] = 'Lis otsikko';
$string['resourcetypetext'] = 'Tee uusi tekstisivu';
$string['searchweb'] = 'Etsi web-sivua';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';
$string['variablename'] = 'Muuttujan nimi';

?>

==> moodle-1.5.tgz: moodle/lang/fi/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005032600)


$string['addresource'] = 'Lis aineisto';
$string['chooseafile'] = 'Valitse tai lhet tiedosto';
$string['chooseparameter'] = 'Valitse parametri';
$string['configdefaulturl'] = 'Tt kytetn esimerkkiosoitteena, kun listn uusia URL-osoiteen sisltvi aineistoja.';
$string['configfilterexternalpages'] = 'Tm asetus aiheuttaa kaikkien ulkoisten aineistoiden suodattamisen sivuston suotimien lpi. Tmn toiminnon kytkeminen plle hidastaa sivustoa, kyt sit vain, jos et muuta voi.';
$string['configframesize'] = 'Kun WWW-sivu tai palvelimelle tallennettu tiedosto on osa kehyst, tm arvo on ylkehyksen koko pikselein (sislt navigointipalkit).';
$string['configparametersettings'] = 'Tss voit mritell oletusarvot asetuksille mit kytetn uusia resursseja listess. Tmn jlkeen oletusasetukset mrytyvt kyttjn asetusten mukaan.';
$string['configpopup'] = 'Jos uusi aineisto on mahdollista nytt ponnahdusikkunassa, otetetaanko ponnahdusikkuna kyttn?';
$string['configpopupdirectories'] = 'Nytetnk ponnahdusikkunoissa hakemistolinkit?';
$string['configpopupheight'] = 'Ponnahdusikkunoiden korkeus?';
$string['configpopuplocation'] = 'Nytetnk ponnahdusikkunoissa sijanti?';
$string['configpopupmenubar'] = 'Nytetnk ponnahdusikkunoissa valikkorivi?';
$string['configpopupresizable'] = 'Voiko ponnahdusikkunoiden kokoa muuttaa?';
$string['configpopupscrollbars'] = 'Nytetnk ponnahdusikkunoissa vierityspalkit?';
$string['configpopupstatus'] = 'Nytetnk ponnahdusikkunoissa tilarivi?';
$string['configpopuptoolbar'] = 'Nytetnk ponnahdusikkunoissa tykalurivi?';
$string['configpopupwidth'] = 'Ponnahdusikkunoiden leveys?';
$string['configsecretphrase'] = 'Tm mritt salasanan jota kytet lhettyjen tietojen salaamiseen.';
$string['configwebsearch'] = 'Kun list WWW-sivun tai -linkin osoite, tt osoitetta tarjotaan kyttjlle etsimisen helpottamiseksi (esimerkiksi sopivan hakukoneen URL).';
$string['configwindowsettings'] = 'Tss mritetn oletus arvot Ikkunan asetuksille kun uusia resursseja listn ensikerran. Tmn jlkeen oletusasetukset mrytyvt kyttjn asetusten mukaan.';
$string['directlink'] = 'Suora linkki thn tiedostoon';
$string['directoryinfo'] = 'Kaikki valitun hakemiston tiedostot nytetn';
$string['display'] = 'Ikkuna';
$string['editingaresource'] = 'Aineiston muokkaus';
$string['encryptedcode'] = 'Suojaa koodi';
$string['example'] = 'Esimerkki';
$string['exampleurl'] = 'http://www.esimerkki.fi/jokuhakemisto/jokutiedosto.html';
$string['fetchclienterror'] = 'Selaimelle tapahtui virhe sivua haettaessa (ehk virheellinen osoite)';
$string['fetcherror'] = 'Tapahtui virhe sivua haettaessa.';
$string['fetchservererror'] = 'Etpalvelimella tapahtui virhe haettaessa sivua (ehk ohjelma virhe)';
$string['filename'] = 'Tiedoston nimi';
$string['filtername'] = 'Aineiston automaattilinkitys';
$string['frameifpossible'] = 'Pane aineisto kehykseen ja jt sivuston navigointipainikkeet nkyviin.';
$string['fulltext'] = 'Teksti';
$string['htmlfragment'] = 'HTML';
$string['maindirectory'] = 'Tiedostojen hakemisto';
$string['modulename'] = 'Aineisto';
$string['modulenameplural'] = 'Aineistot';
$string['neverseen'] = 'Lukematta';
$string['newdirectories'] = 'Nyt linkkirivi';
$string['newfullscreen'] = 'Tyt koko ruutu';
$string['newheight'] = 'Ikkunan oletuskorkeus pikselein';
$string['newlocation'] = 'Nyt osoiterivi';
$string['newmenubar'] = 'Nyt valikkorivi';
$string['newresizable'] = 'Salli ikkunan koon muutos';
$string['newscrollbars'] = 'Nyt vierityspalkki';
$string['newstatus'] = 'Nyt tilarivi';
$string['newtoolbar'] = 'Nyt tykalurivi';
$string['newwidth'] = 'Ikkunan oletusleveys pikselein';
$string['newwindow'] = 'Uusi ikkuna';
$string['newwindowopen'] = 'Nyt linkki uudessa ikkunassa';
$string['note'] = 'Huomaa';
$string['notefile'] = 'Listksesi tiedostoja kurssille (jotta ne nkysivt tss listassa) kyt 
<a href=\"$a\">Tiedostot</a>-tykalua.';
$string['notypechosen'] = 'Sinun pit valita luettavan aineiston tyyppi.  Kyt selaimen Takaisin-painiketta ja yrit uudelleen.';
$string['pagedisplay'] = 'Nyt aineisto nykyisess ikkunassa';
$string['pagewindow'] = 'Samassa ikkunassa';
$string['parameter'] = 'Asetus';
$string['parameters'] = 'Asetukset';
$string['popupresource'] = 'Tmn aineiston tulee nky ponnahdusikkunassa.';
$string['popupresourcelink'] = 'Jos et viel klikannut, klikkaa tss: $a';
$string['resourcetype'] = 'Aineiston tyyppi';
$string['resourcetype1'] = 'Referenssi';
$string['resourcetype2'] = 'Websivu';
$string['resourcetype3'] = 'Tiedosto';
$string['resourcetype4'] = 'Teksti';
$string['resourcetype5'] = 'Weblinkki';
$string['resourcetype6'] = 'HTML teksti';
$string['resourcetype7'] = 'Ohjelma';
$string['resourcetype8'] = 'Wikiteksti';
$string['resourcetype9'] = 'Hakemisto';
$string['resourcetypedirectory'] = 'Nyt hakemisto';
$string['resourcetypefile'] = 'Linkit  tiedostoon tai web-sivuun';
$string['resourcetypehtml'] = 'Tee uusi web-sivu';
$string['resourcetypelabel'] = 'Lis otsikko';
$string['resourcetypetext'] = 'Tee uusi tekstisivu';
$string['searchweb'] = 'Etsi web-sivua';
$string['variablename'] = 'Muuttujan nimi';

?>
